'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var constants = require('../constants.js');
var util = require('./util.js');

const toSocketIoMessagePayload = (id, data) => {
  return `${constants.packetTypes.send}${id}${JSON.stringify(['socket.io-request', data])}`;
}; // 430[{...}}] => 430, [{}]
// @see https://github.com/socketio/engine.io-protocol

const parseMessage = message => {
  let packetType = '';

  while (message.length) {
    const head = message[0];

    if (util.isIntegerString(head)) {
      packetType += head;
      message = message.substr(1);
    } else {
      return [packetType, JSON.parse(message)];
    }
  }

  return [packetType, undefined];
};
const isConnectionMessage = message => {
  return message[0] === constants.packetTypes.initialize;
};
const isResponseMessage = message => {
  return message[0].length > 2 && message[0].startsWith(constants.packetTypes.response);
};
const getRequestId = packetType => packetType.slice(2);
const isResponseMessageOf = sid => message => {
  return isResponseMessage(message) && sid === getRequestId(message[0]);
};

exports.getRequestId = getRequestId;
exports.isConnectionMessage = isConnectionMessage;
exports.isResponseMessage = isResponseMessage;
exports.isResponseMessageOf = isResponseMessageOf;
exports.parseMessage = parseMessage;
exports.toSocketIoMessagePayload = toSocketIoMessagePayload;
//# sourceMappingURL=message.js.map
