'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var rxjs = require('rxjs');
var operators = require('rxjs/operators');
var env = require('../../common/env.js');

const getBrowserWebSocket = ({
  endpoint
}) => new WebSocket(endpoint);
const getNodeJSWebSocket = ({
  endpoint,
  origin,
  cookie
}) => {
  const NodeWebsocket = require('ws');

  const headers = {
    Origin: origin,
    Cookie: cookie
  };
  return new NodeWebsocket(endpoint, undefined, {
    headers
  });
};
const getWebSocket = settings => {
  if (env.isBrowser()) {
    // @TODO: validate settings
    return getBrowserWebSocket(settings);
  } else {
    // @TODO: validate settings
    return getNodeJSWebSocket(settings);
  }
};
const getEventStream = socket => {
  const close = rxjs.fromEvent(socket, 'close').pipe(operators.first());
  const open = rxjs.fromEvent(socket, 'open').pipe(operators.takeUntil(close), operators.shareReplay());
  const error = rxjs.fromEvent(socket, 'error').pipe(operators.takeUntil(close), operators.shareReplay());
  const message = rxjs.fromEvent(socket, 'message').pipe(operators.takeUntil(close));
  return {
    open,
    close,
    error,
    message
  };
};

exports.getBrowserWebSocket = getBrowserWebSocket;
exports.getEventStream = getEventStream;
exports.getNodeJSWebSocket = getNodeJSWebSocket;
exports.getWebSocket = getWebSocket;
//# sourceMappingURL=websocket.js.map
