import { fromEvent } from 'rxjs';
import { first, takeUntil, shareReplay } from 'rxjs/operators';
import { isBrowser } from '../../common/env.js';

const getBrowserWebSocket = ({ endpoint }) => new WebSocket(endpoint);
const getNodeJSWebSocket = ({ endpoint, origin, cookie }) => {
    const NodeWebsocket = require('ws');
    const headers = { Origin: origin, Cookie: cookie };
    return new NodeWebsocket(endpoint, undefined, { headers });
};
const getWebSocket = (settings) => {
    if (isBrowser()) {
        // @TODO: validate settings
        return getBrowserWebSocket(settings);
    }
    else {
        // @TODO: validate settings
        return getNodeJSWebSocket(settings);
    }
};
const getEventStream = (socket) => {
    const close = fromEvent(socket, 'close').pipe(first());
    const open = fromEvent(socket, 'open').pipe(takeUntil(close), shareReplay());
    const error = fromEvent(socket, 'error').pipe(takeUntil(close), shareReplay());
    const message = fromEvent(socket, 'message').pipe(takeUntil(close));
    return { open, close, error, message };
};

export { getBrowserWebSocket, getEventStream, getNodeJSWebSocket, getWebSocket };
//# sourceMappingURL=websocket.js.map
